@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
+ *   Copyright (C) 2007-2018 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -260,66 +260,69 @@ void check_file_save(const char * const filename)
 
 	GString *string = g_string_sized_new(1024);
 
-	for (int i = 0; i < HASH_FUNCS_N; i++) {
+	for (enum hash_func_e i = 0; i < HASH_FUNCS_N; i++) {
 		if (!hash.funcs[i].enabled)
 			continue;
 
 		switch (gui.view) {
 			case GUI_VIEW_FILE: {
-				const bool hmac_active = gtk_toggle_button_get_active(
-					gui.togglebutton_hmac_file);
 				const char *digest = gtk_entry_get_text(
 					gui.hash_widgets[i].entry_file);
-				if (digest && *digest) {
-					g_string_append_printf(string,
-						(hmac_active && hash.funcs[i].hmac_supported) ?
-						"# HMAC-%s\n" : "# %s\n", hash.funcs[i].name);
-				} else
+				if (!(digest && *digest))
 					continue;
-				char *path = gtk_file_chooser_get_filename(
+
+				const bool hmac_active = gtk_toggle_button_get_active(
+					gui.togglebutton_hmac_file);
+
+				g_string_append_printf(string,
+					(hmac_active && hash.funcs[i].hmac_supported) ?
+					"# HMAC-%s\n" : "# %s\n", hash.funcs[i].name);
+
+				GFile *file = gtk_file_chooser_get_file(
 					GTK_FILE_CHOOSER(gui.filechooserbutton));
-				char *basename = g_path_get_basename(path);
-				g_free(path);
+				char *basename = g_file_get_basename(file);
+
 				g_string_append_printf(string, "%s  %s\n",
-				gtk_entry_get_text(gui.hash_widgets[i].entry_file),
-					basename);
+					gtk_entry_get_text(gui.hash_widgets[i].entry_file),
+						basename);
+
 				g_free(basename);
+				g_object_unref(file);
+
 				break;
 			}
 			case GUI_VIEW_TEXT: {
 				const bool hmac_active = gtk_toggle_button_get_active(
 					gui.togglebutton_hmac_text);
+
 				g_string_append_printf(string,
 					(hmac_active && hash.funcs[i].hmac_supported) ?
 					"# HMAC-%s\n" : "# %s\n", hash.funcs[i].name);
 				g_string_append_printf(string, "%s  \"%s\"\n",
 					gtk_entry_get_text(gui.hash_widgets[i].entry_text),
 					gtk_entry_get_text(gui.entry_text));
+
 				break;
 			}
 			case GUI_VIEW_FILE_LIST: {
-				int prev = -1;
-				for (unsigned int row = 0; row < list.rows; row++)
-				{
+				enum hash_func_e prev = HASH_FUNC_INVALID;
+
+				for (unsigned int row = 0; row < list.rows; row++) {
 					char *digest = list_get_digest(row, i);
+
 					if (digest && *digest) {
-						if (i != prev)
+						if (i != prev) {
 							g_string_append_printf(string, "# %s\n",
 								hash.funcs[i].name);
-						prev = i;
-					} else {
-						if (digest)
-							g_free(digest);
-						prev = i;
-						continue;
+						}
+						char *basename = list_get_basename(row);
+						g_string_append_printf(string, "%s  %s\n",
+							digest, basename);
+						g_free(basename);
 					}
-					char *uri = list_get_uri(row);
-					char *basename = g_filename_display_basename(uri);
-					g_string_append_printf(string, "%s  %s\n",
-						digest, basename);
-					g_free(basename);
-					g_free(uri);
+
 					g_free(digest);
+					prev = i;
 				}
 				break;
 			}
