@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2011 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifndef GTKHASH_HASH_H
@@ -31,6 +31,8 @@ void hash_file_start(const char *uri);
 void hash_file_list_start(void);
 void hash_file_stop(void);
 void hash_string(void);
+unsigned int hash_funcs_count_enabled(void);
+void hash_funcs_enable_strv(const char **funcs);
 void hash_init(void);
 void hash_deinit(void);
 
