@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2011 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifndef GTKHASH_HASH_DIGEST_H
@@ -32,14 +32,13 @@
 struct digest_s {
 	uint8_t *bin;
 	size_t size;
-	char *data[DIGEST_FORMATS_N];
 };
 
 struct digest_s *gtkhash_digest_new(void);
 void gtkhash_digest_set_data(struct digest_s *digest, uint8_t *bin,
 	size_t size);
-const char *gtkhash_digest_get_data(struct digest_s *digest,
-	const enum digest_format_e format);
+char *gtkhash_digest_get_data(struct digest_s *digest,
+	enum digest_format_e format);
 void gtkhash_digest_free_data(struct digest_s *digest);
 void gtkhash_digest_free(struct digest_s *digest);
 
