@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
+ *   Copyright (C) 2007-2018 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -43,6 +43,10 @@ static bool gtkhash_hash_lib_gcrypt_set_algo(const enum hash_func_e id,
 	int *algo)
 {
 	switch (id) {
+#if ((GCRYPT_VERSION_NUMBER) >= 0x010800)
+		case HASH_FUNC_BLAKE2B:   *algo = GCRY_MD_BLAKE2B_512;  break;
+		case HASH_FUNC_BLAKE2S:   *algo = GCRY_MD_BLAKE2S_256;  break;
+#endif
 		case HASH_FUNC_GOST:      *algo = GCRY_MD_GOSTR3411_94; break;
 		case HASH_FUNC_MD4:       *algo = GCRY_MD_MD4;          break;
 		case HASH_FUNC_MD5:       *algo = GCRY_MD_MD5;          break;
@@ -52,10 +56,12 @@ static bool gtkhash_hash_lib_gcrypt_set_algo(const enum hash_func_e id,
 		case HASH_FUNC_SHA256:    *algo = GCRY_MD_SHA256;       break;
 		case HASH_FUNC_SHA384:    *algo = GCRY_MD_SHA384;       break;
 		case HASH_FUNC_SHA512:    *algo = GCRY_MD_SHA512;       break;
+#if ((GCRYPT_VERSION_NUMBER) >= 0x010700)
 		case HASH_FUNC_SHA3_224:  *algo = GCRY_MD_SHA3_224;     break;
 		case HASH_FUNC_SHA3_256:  *algo = GCRY_MD_SHA3_256;     break;
 		case HASH_FUNC_SHA3_384:  *algo = GCRY_MD_SHA3_384;     break;
 		case HASH_FUNC_SHA3_512:  *algo = GCRY_MD_SHA3_512;     break;
+#endif
 		case HASH_FUNC_TIGER192:  *algo = GCRY_MD_TIGER;        break;
 		case HASH_FUNC_WHIRLPOOL: *algo = GCRY_MD_WHIRLPOOL;    break;
 
@@ -73,6 +79,11 @@ bool gtkhash_hash_lib_gcrypt_is_supported(const enum hash_func_e id)
 	if (!gtkhash_hash_lib_gcrypt_set_algo(id, &data.algo))
 		return false;
 
+	if (!gcry_check_version(HASH_LIB_GCRYPT_MIN_VER)) {
+		g_warning("gcrypt-" HASH_LIB_GCRYPT_MIN_VER " is required");
+		return false;
+	}
+
 	if (G_UNLIKELY(gcry_md_open(&data.h, data.algo, 0) != GPG_ERR_NO_ERROR)) {
 		g_warning("gcry_md_open failed (%d)", id);
 		return false;
