@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2013 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,10 +27,11 @@
 #include <glib.h>
 #include <mhash.h>
 
-#include "hash-lib-mhash.h"
 #include "hash-lib.h"
 #include "hash-func.h"
 
+HASH_LIB_DECL(mhash)
+
 #define LIB_DATA ((struct hash_lib_mhash_s *)func->lib_data)
 
 struct hash_lib_mhash_s {
@@ -42,78 +43,29 @@ static bool gtkhash_hash_lib_mhash_set_type(const enum hash_func_e id,
 	hashid *type)
 {
 	switch (id) {
-		case HASH_FUNC_GOST:
-			*type = MHASH_GOST;
-			break;
-		case HASH_FUNC_HAVAL128_3:
-			*type = MHASH_HAVAL128;
-			break;
-		case HASH_FUNC_HAVAL160_3:
-			*type = MHASH_HAVAL160;
-			break;
-		case HASH_FUNC_HAVAL192_3:
-			*type = MHASH_HAVAL192;
-			break;
-		case HASH_FUNC_HAVAL224_3:
-			*type = MHASH_HAVAL224;
-			break;
-		case HASH_FUNC_HAVAL256_3:
-			*type = MHASH_HAVAL256;
-			break;
-		case HASH_FUNC_MD2:
-			*type = MHASH_MD2;
-			break;
-		case HASH_FUNC_MD4:
-			*type = MHASH_MD4;
-			break;
-		case HASH_FUNC_MD5:
-			*type = MHASH_MD5;
-			break;
-		case HASH_FUNC_RIPEMD128:
-			*type = MHASH_RIPEMD128;
-			break;
-		case HASH_FUNC_RIPEMD160:
-			*type = MHASH_RIPEMD160;
-			break;
-		case HASH_FUNC_RIPEMD256:
-			*type = MHASH_RIPEMD256;
-			break;
-		case HASH_FUNC_RIPEMD320:
-			*type = MHASH_RIPEMD320;
-			break;
-		case HASH_FUNC_SHA1:
-			*type = MHASH_SHA1;
-			break;
-		case HASH_FUNC_SHA224:
-			*type = MHASH_SHA224;
-			break;
-		case HASH_FUNC_SHA256:
-			*type = MHASH_SHA256;
-			break;
-		case HASH_FUNC_SHA384:
-			*type = MHASH_SHA384;
-			break;
-		case HASH_FUNC_SHA512:
-			*type = MHASH_SHA512;
-			break;
-		case HASH_FUNC_SNEFRU128:
-			*type = MHASH_SNEFRU128;
-			break;
-		case HASH_FUNC_SNEFRU256:
-			*type = MHASH_SNEFRU256;
-			break;
-		case HASH_FUNC_TIGER128:
-			*type = MHASH_TIGER128;
-			break;
-		case HASH_FUNC_TIGER160:
-			*type = MHASH_TIGER160;
-			break;
-		case HASH_FUNC_TIGER192:
-			*type = MHASH_TIGER192;
-			break;
-		case HASH_FUNC_WHIRLPOOL:
-			*type = MHASH_WHIRLPOOL;
-			break;
+		case HASH_FUNC_GOST:       *type = MHASH_GOST;      break;
+		case HASH_FUNC_HAVAL128_3: *type = MHASH_HAVAL128;  break;
+		case HASH_FUNC_HAVAL160_3: *type = MHASH_HAVAL160;  break;
+		case HASH_FUNC_HAVAL192_3: *type = MHASH_HAVAL192;  break;
+		case HASH_FUNC_HAVAL224_3: *type = MHASH_HAVAL224;  break;
+		case HASH_FUNC_HAVAL256_3: *type = MHASH_HAVAL256;  break;
+		case HASH_FUNC_MD2:        *type = MHASH_MD2;       break;
+		case HASH_FUNC_MD4:        *type = MHASH_MD4;       break;
+		case HASH_FUNC_MD5:        *type = MHASH_MD5;       break;
+		case HASH_FUNC_RIPEMD128:  *type = MHASH_RIPEMD128; break;
+		case HASH_FUNC_RIPEMD160:  *type = MHASH_RIPEMD160; break;
+		case HASH_FUNC_RIPEMD256:  *type = MHASH_RIPEMD256; break;
+		case HASH_FUNC_RIPEMD320:  *type = MHASH_RIPEMD320; break;
+		case HASH_FUNC_SHA1:       *type = MHASH_SHA1;      break;
+		case HASH_FUNC_SHA224:     *type = MHASH_SHA224;    break;
+		case HASH_FUNC_SHA256:     *type = MHASH_SHA256;    break;
+		case HASH_FUNC_SHA384:     *type = MHASH_SHA384;    break;
+		case HASH_FUNC_SHA512:     *type = MHASH_SHA512;    break;
+		case HASH_FUNC_SNEFRU128:  *type = MHASH_SNEFRU128; break;
+		case HASH_FUNC_SNEFRU256:  *type = MHASH_SNEFRU256; break;
+		case HASH_FUNC_TIGER192:   *type = MHASH_TIGER192;  break;
+		case HASH_FUNC_WHIRLPOOL:  *type = MHASH_WHIRLPOOL; break;
+
 		default:
 			return false;
 	}
