@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
+ *   Copyright (C) 2007-2017 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -40,7 +40,7 @@
 	HASH_LIB_DECL(glib)
 #endif
 #if ENABLE_LIBCRYPTO
-	HASH_LIB_DECL(crypt)
+	HASH_LIB_DECL(crypto)
 #endif
 #if ENABLE_LINUX_CRYPTO
 	HASH_LIB_DECL(linux)
@@ -57,12 +57,6 @@
 #if ENABLE_NETTLE
 	HASH_LIB_DECL(nettle)
 #endif
-#if ENABLE_NSS
-	HASH_LIB_DECL(nss)
-#endif
-#if ENABLE_POLARSSL
-	HASH_LIB_DECL(polarssl)
-#endif
 #if ENABLE_ZLIB
 	HASH_LIB_DECL(zlib)
 #endif
@@ -96,12 +90,6 @@ enum hash_lib_e {
 #if ENABLE_NETTLE
 	HASH_LIB_NETTLE,
 #endif
-#if ENABLE_NSS
-	HASH_LIB_NSS,
-#endif
-#if ENABLE_POLARSSL
-	HASH_LIB_POLARSSL,
-#endif
 #if ENABLE_ZLIB
 	HASH_LIB_ZLIB,
 #endif
@@ -124,9 +112,9 @@ static void gtkhash_hash_lib_init_once(void)
 			continue;
 		}
 #endif
-#if ENABLE_LINUX_CRYPTO
-		if (gtkhash_hash_lib_linux_is_supported(i)) {
-			hash_libs[i] = HASH_LIB_LINUX;
+#if ENABLE_BLAKE2
+		if (gtkhash_hash_lib_blake2_is_supported(i)) {
+			hash_libs[i] = HASH_LIB_BLAKE2;
 			continue;
 		}
 #endif
@@ -148,21 +136,15 @@ static void gtkhash_hash_lib_init_once(void)
 			continue;
 		}
 #endif
-#if ENABLE_POLARSSL
-		if (gtkhash_hash_lib_polarssl_is_supported(i)) {
-			hash_libs[i] = HASH_LIB_POLARSSL;
-			continue;
-		}
-#endif
 #if ENABLE_NETTLE
 		if (gtkhash_hash_lib_nettle_is_supported(i)) {
 			hash_libs[i] = HASH_LIB_NETTLE;
 			continue;
 		}
 #endif
-#if ENABLE_NSS
-		if (gtkhash_hash_lib_nss_is_supported(i)) {
-			hash_libs[i] = HASH_LIB_NSS;
+#if ENABLE_LINUX_CRYPTO
+		if (gtkhash_hash_lib_linux_is_supported(i)) {
+			hash_libs[i] = HASH_LIB_LINUX;
 			continue;
 		}
 #endif
@@ -178,12 +160,6 @@ static void gtkhash_hash_lib_init_once(void)
 			continue;
 		}
 #endif
-#if ENABLE_BLAKE2
-		if (gtkhash_hash_lib_blake2_is_supported(i)) {
-			hash_libs[i] = HASH_LIB_BLAKE2;
-			continue;
-		}
-#endif
 #if ENABLE_MD6
 		if (gtkhash_hash_lib_md6_is_supported(i)) {
 			hash_libs[i] = HASH_LIB_MD6;
@@ -238,12 +214,6 @@ void gtkhash_hash_lib_start(struct hash_func_s *func, const uint8_t *hmac_key,
 #if ENABLE_NETTLE
 		[HASH_LIB_NETTLE] = gtkhash_hash_lib_nettle_start,
 #endif
-#if ENABLE_NSS
-		[HASH_LIB_NSS] = gtkhash_hash_lib_nss_start,
-#endif
-#if ENABLE_POLARSSL
-		[HASH_LIB_POLARSSL] = gtkhash_hash_lib_polarssl_start,
-#endif
 #if ENABLE_ZLIB
 		[HASH_LIB_ZLIB] = gtkhash_hash_lib_zlib_start,
 #endif
@@ -295,12 +265,6 @@ void gtkhash_hash_lib_update(struct hash_func_s *func, const uint8_t *buffer,
 #if ENABLE_NETTLE
 		[HASH_LIB_NETTLE] = gtkhash_hash_lib_nettle_update,
 #endif
-#if ENABLE_NSS
-		[HASH_LIB_NSS] = gtkhash_hash_lib_nss_update,
-#endif
-#if ENABLE_POLARSSL
-		[HASH_LIB_POLARSSL] = gtkhash_hash_lib_polarssl_update,
-#endif
 #if ENABLE_ZLIB
 		[HASH_LIB_ZLIB] = gtkhash_hash_lib_zlib_update,
 #endif
@@ -345,12 +309,6 @@ void gtkhash_hash_lib_stop(struct hash_func_s *func)
 #if ENABLE_NETTLE
 		[HASH_LIB_NETTLE] = gtkhash_hash_lib_nettle_stop,
 #endif
-#if ENABLE_NSS
-		[HASH_LIB_NSS] = gtkhash_hash_lib_nss_stop,
-#endif
-#if ENABLE_POLARSSL
-		[HASH_LIB_POLARSSL] = gtkhash_hash_lib_polarssl_stop,
-#endif
 #if ENABLE_ZLIB
 		[HASH_LIB_ZLIB] = gtkhash_hash_lib_zlib_stop,
 #endif
@@ -399,12 +357,6 @@ void gtkhash_hash_lib_finish(struct hash_func_s *func)
 #if ENABLE_NETTLE
 		[HASH_LIB_NETTLE] = gtkhash_hash_lib_nettle_finish,
 #endif
-#if ENABLE_NSS
-		[HASH_LIB_NSS] = gtkhash_hash_lib_nss_finish,
-#endif
-#if ENABLE_POLARSSL
-		[HASH_LIB_POLARSSL] = gtkhash_hash_lib_polarssl_finish,
-#endif
 #if ENABLE_ZLIB
 		[HASH_LIB_ZLIB] = gtkhash_hash_lib_zlib_finish,
 #endif
