@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2011 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifndef GTKHASH_HASH_HASH_STRING_H
@@ -23,10 +23,9 @@
 #include "hash-func.h"
 
 void gtkhash_hash_string(struct hash_func_s *funcs, const char *str,
-	const enum digest_format_e format, const uint8_t *hmac_key,
-	const size_t key_size);
+	enum digest_format_e format, const uint8_t *hmac_key, size_t key_size);
 
-void gtkhash_hash_string_finish_cb(const enum hash_func_e id,
-	const char *digest);
+void gtkhash_hash_string_digest_cb(enum hash_func_e id, const char *digest);
+void gtkhash_hash_string_finish_cb(void);
 
 #endif
