@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2013 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,17 +31,22 @@
 #include "gui.h"
 #include "list.h"
 #include "prefs.h"
+#include "resources.h"
+#include "check.h"
+#include "uri-digest.h"
 
 static struct {
-	char *check;
-	char *datadir;
-	char *text;
-	char **files;
+	const char *check;
+	const char **check_files;
+	const char *text;
+	const char **funcs;
+	const char **files;
 	gboolean version;
 } opts = {
 	.check = NULL,
-	.datadir = NULL,
+	.check_files = NULL,
 	.text = NULL,
+	.funcs = NULL,
 	.files = NULL,
 	.version = false,
 };
@@ -49,27 +54,32 @@ static struct {
 static void free_opts(void)
 {
 	if (opts.check) {
-		g_free(opts.check);
+		g_free((void *)opts.check);
 		opts.check = NULL;
 	}
 
-	if (opts.datadir) {
-		g_free(opts.datadir);
-		opts.datadir = NULL;
+	if (opts.check_files) {
+		g_strfreev((char **)opts.check_files);
+		opts.check_files = NULL;
 	}
 
 	if (opts.text) {
-		g_free(opts.text);
+		g_free((void *)opts.text);
 		opts.text = NULL;
 	}
 
+	if (opts.funcs) {
+		g_strfreev((char **)opts.funcs);
+		opts.funcs = NULL;
+	}
+
 	if (opts.files) {
-		g_strfreev(opts.files);
+		g_strfreev((char **)opts.files);
 		opts.files = NULL;
 	}
 }
 
-static char *filename_arg_to_uri(const char *arg)
+static char *filename_arg_to_uri(const char * const arg)
 {
 	GFile *file = g_file_new_for_commandline_arg(arg);
 	char *uri = g_file_get_uri(file);
@@ -83,23 +93,34 @@ static void read_opts_preinit(int *argc, char ***argv)
 	GOptionEntry entries[] = {
 		{
 			"check", 'c', 0, G_OPTION_ARG_STRING, &opts.check,
-			_("Check against the specified digest or checksum"), _("DIGEST")
+			C_(PACKAGE " --help",
+				"Check against the specified digest or checksum"),
+			C_(PACKAGE " --help", "DIGEST")
 		},
 		{
-			"datadir", 'd', 0, G_OPTION_ARG_FILENAME, &opts.datadir,
-			_("Read program data from the specified directory"), _("DIRECTORY")
+			"check-file", 'C', 0, G_OPTION_ARG_STRING_ARRAY, &opts.check_files,
+			C_(PACKAGE " --help",
+				"Check digests or checksums from the specified file"),
+			C_(PACKAGE " --help", "FILE|URI")
+		},
+		{
+			"function", 'f', 0, G_OPTION_ARG_STRING_ARRAY, &opts.funcs,
+			C_(PACKAGE " --help",
+				"Enable the specified Hash Function (e.g. MD5)"),
+			C_(PACKAGE " --help", "FUNCTION")
 		},
 		{
 			"text", 't', 0, G_OPTION_ARG_STRING, &opts.text,
-			_("Hash the specified text"), _("TEXT")
+			C_(PACKAGE " --help", "Hash the specified text"),
+			C_(PACKAGE " --help", "TEXT")
 		},
 		{
 			"version", 'v', 0, G_OPTION_ARG_NONE, &opts.version,
-			_("Show version information"), NULL
+			C_(PACKAGE " --help", "Show version information"), NULL
 		},
 		{
 			G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_FILENAME_ARRAY, &opts.files,
-			NULL, _("[FILE|URI...]")
+			NULL, C_(PACKAGE " --help", "[FILE|URI...]")
 		},
 		{ NULL, 0, 0, 0, NULL, NULL, NULL }
 	};
@@ -107,8 +128,6 @@ static void read_opts_preinit(int *argc, char ***argv)
 	GOptionContext *context = g_option_context_new(NULL);
 	GError *error = NULL;
 
-	atexit(free_opts);
-
 	g_option_context_add_main_entries(context, entries, GETTEXT_PACKAGE);
 	g_option_context_add_group(context, gtk_get_option_group(false));
 	g_option_context_parse(context, argc, argv, &error);
@@ -117,41 +136,59 @@ static void read_opts_preinit(int *argc, char ***argv)
 	if (error) {
 		g_warning("%s", error->message);
 		g_error_free(error);
+		free_opts();
 		exit(EXIT_FAILURE);
 	}
 
 	if (opts.version) {
 		printf("%s\n", PACKAGE_STRING);
+		free_opts();
 		exit(EXIT_SUCCESS);
 	}
+
+	if (opts.funcs)
+		hash_funcs_enable_strv(opts.funcs);
 }
 
 static void read_opts_postinit(void)
 {
-	if (opts.files) {
-		GSList *uris = NULL;
-
-		for (int i = 0; opts.files[i]; i++)
-			uris = g_slist_prepend(uris, filename_arg_to_uri(opts.files[i]));
-
-		uris = g_slist_reverse(uris);
-
-		unsigned int added = gui_add_uris(uris, GUI_VIEW_INVALID);
-		if (added == 1)
-			gui_set_view(GUI_VIEW_FILE);
-		else if (added > 1)
-			gui_set_view(GUI_VIEW_FILE_LIST);
-
-		g_slist_free_full(uris, g_free);
-	}
-
 	if (opts.check && *opts.check)
 		gui_add_check(opts.check);
 
-	if (opts.text && *opts.text) {
+	GSList *ud_list = NULL;
+
+	if (opts.check_files) {
+		for (int i = 0; opts.check_files[i]; i++) {
+			GFile *file = g_file_new_for_commandline_arg(opts.check_files[i]);
+			ud_list = check_file_load(ud_list, file);
+			g_object_unref(file);
+		}
+	}
+
+	if (opts.files) {
+		for (int i = 0; opts.files[i]; i++) {
+			struct uri_digest_s *ud =
+				uri_digest_new(filename_arg_to_uri(opts.files[i]), NULL);
+			ud_list = g_slist_prepend(ud_list, ud);
+		}
+	}
+
+	bool files_added = false;
+
+	if (ud_list) {
+		ud_list = g_slist_reverse(ud_list);
+		files_added = gui_add_ud_list(ud_list, GUI_VIEW_INVALID);
+		uri_digest_list_free_full(ud_list);
+	}
+
+	if (files_added) {
+		gui_update();
+		gui_start_hash();
+	} else if (opts.text) {
 		gui_add_text(opts.text);
-		if (!opts.files)
-			gui_set_view(GUI_VIEW_TEXT);
+	} else if (GUI_VIEW_IS_VALID(gui.view)) {
+		// view was loaded from prefs
+		gui_update();
 	}
 
 	free_opts();
@@ -165,23 +202,27 @@ int main(int argc, char **argv)
 	textdomain(GETTEXT_PACKAGE);
 #endif
 
-	gdk_threads_init();
-	gdk_threads_enter();
-	atexit(gdk_threads_leave);
-
-	read_opts_preinit(&argc, &argv);
-
 	hash_init();
 	atexit(hash_deinit);
 
-	gui_init(opts.datadir ? opts.datadir : DATADIR);
+	read_opts_preinit(&argc, &argv);
+
+	gtk_init(NULL, NULL);
+
+	// Init gui using GResource data
+	resources_register_resource();
+	gui_init();
 	atexit(gui_deinit);
+	resources_unregister_resource();
 
 	list_init();
 
 	prefs_init();
 	atexit(prefs_deinit);
 
+	check_init();
+	atexit(check_deinit);
+
 	read_opts_postinit();
 
 	gui_run();
