@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2011 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifndef GTKHASH_NAUTILUS_PROPERTIES_LIST_H
@@ -22,9 +22,13 @@
 
 #include "properties.h"
 
-void gtkhash_properties_list_update_enabled(struct page_s *page, char *path_str);
-void gtkhash_properties_list_update_digests(struct page_s *page);
+void gtkhash_properties_list_update_enabled(struct page_s *page,
+	char *path_str);
+void gtkhash_properties_list_update_hash_func_names(struct page_s *page);
+void gtkhash_properties_list_clear_digests(struct page_s *page);
 void gtkhash_properties_list_check_digests(struct page_s *page);
+void gtkhash_properties_list_set_digest(struct page_s *page, enum hash_func_e id,
+	const char *digest);
 char *gtkhash_properties_list_get_selected_digest(struct page_s *page);
 void gtkhash_properties_list_refilter(struct page_s *page);
 void gtkhash_properties_list_init(struct page_s *page);
