@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2017 Tristan Heaven <tristan@tristanheaven.net>
+ *   Copyright (C) 2007-2018 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -35,6 +35,10 @@
 #elif IN_NEMO_EXTENSION
 	#include <libnemo-extension/nemo-property-page.h>
 	#include <libnemo-extension/nemo-property-page-provider.h>
+	#include <libnemo-extension/nemo-name-and-desc-provider.h>
+#elif IN_PEONY_EXTENSION
+	#include <libpeony-extension/peony-property-page.h>
+	#include <libpeony-extension/peony-property-page-provider.h>
 #elif IN_THUNAR_EXTENSION
 	#include <thunarx/thunarx.h>
 #endif
@@ -435,6 +439,8 @@ static GList *gtkhash_properties_get_pages(
 	G_GNUC_UNUSED CajaPropertyPageProvider *provider,
 #elif IN_NEMO_EXTENSION
 	G_GNUC_UNUSED NemoPropertyPageProvider *provider,
+#elif IN_PEONY_EXTENSION
+	G_GNUC_UNUSED PeonyPropertyPageProvider *provider,
 #elif IN_THUNAR_EXTENSION
 	G_GNUC_UNUSED ThunarxPropertyPageProvider *provider,
 #endif
@@ -453,6 +459,9 @@ static GList *gtkhash_properties_get_pages(
 #elif IN_NEMO_EXTENSION
 	GFileType type = nemo_file_info_get_file_type(files->data);
 	char *uri = nemo_file_info_get_uri(files->data);
+#elif IN_PEONY_EXTENSION
+	GFileType type = peony_file_info_get_file_type(files->data);
+	char *uri = peony_file_info_get_uri(files->data);
 #elif IN_THUNAR_EXTENSION
 	GFileInfo *info = thunarx_file_info_get_file_info(files->data);
 	GFileType type = g_file_info_get_file_type(info);
@@ -478,6 +487,9 @@ static GList *gtkhash_properties_get_pages(
 #elif IN_NEMO_EXTENSION
 	NemoPropertyPage *ppage = nemo_property_page_new(
 		"GtkHash::properties", gtk_label_new(_("Digests")), page->box);
+#elif IN_PEONY_EXTENSION
+	PeonyPropertyPage *ppage = peony_property_page_new(
+		"GtkHash::properties", gtk_label_new(_("Digests")), page->box);
 #elif IN_THUNAR_EXTENSION
 	GtkWidget *ppage = thunarx_property_page_new(_("Digests"));
 	gtk_container_add(GTK_CONTAINER(ppage), page->box);
@@ -488,21 +500,39 @@ static GList *gtkhash_properties_get_pages(
 	return pages;
 }
 
-static void gtkhash_properties_iface_init(
+static void gtkhash_properties_pp_iface_init(
 #if IN_NAUTILUS_EXTENSION
-	NautilusPropertyPageProviderIface *iface
+	NautilusPropertyPageProviderIface *iface,
 #elif IN_CAJA_EXTENSION
-	CajaPropertyPageProviderIface *iface
+	CajaPropertyPageProviderIface *iface,
 #elif IN_NEMO_EXTENSION
-	NemoPropertyPageProviderIface *iface
+	NemoPropertyPageProviderIface *iface,
+#elif IN_PEONY_EXTENSION
+	PeonyPropertyPageProviderIface *iface,
 #elif IN_THUNAR_EXTENSION
-	ThunarxPropertyPageProviderIface *iface
+	ThunarxPropertyPageProviderIface *iface,
 #endif
-	)
+	G_GNUC_UNUSED void *data)
 {
 	iface->get_pages = gtkhash_properties_get_pages;
 }
 
+#if IN_NEMO_EXTENSION
+static char *gtkhash_properties_nd_string = NULL;
+
+static GList *gtkhash_properties_get_name_desc(
+	G_GNUC_UNUSED NemoNameAndDescProvider *provider)
+{
+	return g_list_append(NULL, gtkhash_properties_nd_string);
+}
+
+static void gtkhash_properties_nd_iface_init(NemoNameAndDescProviderIface *iface,
+	G_GNUC_UNUSED void *data)
+{
+	iface->get_name_and_desc = gtkhash_properties_get_name_desc;
+}
+#endif
+
 static void gtkhash_properties_register_type(GTypeModule *module)
 {
 	const GTypeInfo info = {
@@ -521,8 +551,8 @@ static void gtkhash_properties_register_type(GTypeModule *module)
 	page_type = g_type_module_register_type(module, G_TYPE_OBJECT,
 		"GtkHash", &info, 0);
 
-	const GInterfaceInfo iface_info = {
-		(GInterfaceInitFunc)gtkhash_properties_iface_init,
+	const GInterfaceInfo pp_iface_info = {
+		(GInterfaceInitFunc)gtkhash_properties_pp_iface_init,
 		(GInterfaceFinalizeFunc)NULL,
 		NULL
 	};
@@ -534,10 +564,23 @@ static void gtkhash_properties_register_type(GTypeModule *module)
 		CAJA_TYPE_PROPERTY_PAGE_PROVIDER,
 #elif IN_NEMO_EXTENSION
 		NEMO_TYPE_PROPERTY_PAGE_PROVIDER,
+#elif IN_PEONY_EXTENSION
+		PEONY_TYPE_PROPERTY_PAGE_PROVIDER,
 #elif IN_THUNAR_EXTENSION
 		THUNARX_TYPE_PROPERTY_PAGE_PROVIDER,
 #endif
-		&iface_info);
+		&pp_iface_info);
+
+#if IN_NEMO_EXTENSION
+	const GInterfaceInfo nd_iface_info = {
+		(GInterfaceInitFunc)gtkhash_properties_nd_iface_init,
+		(GInterfaceFinalizeFunc)NULL,
+		NULL
+	};
+
+	g_type_module_add_interface(module, page_type,
+		NEMO_TYPE_NAME_AND_DESC_PROVIDER, &nd_iface_info);
+#endif
 }
 
 #if __GNUC__
@@ -552,6 +595,8 @@ PUBLIC void nautilus_module_initialize(GTypeModule *module)
 PUBLIC void caja_module_initialize(GTypeModule *module)
 #elif IN_NEMO_EXTENSION
 PUBLIC void nemo_module_initialize(GTypeModule *module)
+#elif IN_PEONY_EXTENSION
+PUBLIC void peony_module_initialize(GTypeModule *module)
 #elif IN_THUNAR_EXTENSION
 PUBLIC void thunar_extension_initialize(GTypeModule *module);
 PUBLIC void thunar_extension_initialize(GTypeModule *module)
@@ -563,6 +608,11 @@ PUBLIC void thunar_extension_initialize(GTypeModule *module)
 	bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 #endif
+
+#if IN_NEMO_EXTENSION
+	gtkhash_properties_nd_string = g_strdup_printf("GtkHash:::%s",
+		_("Calculate message digests or checksums"));
+#endif
 }
 
 #if IN_NAUTILUS_EXTENSION
@@ -571,11 +621,17 @@ PUBLIC void nautilus_module_shutdown(void)
 PUBLIC void caja_module_shutdown(void)
 #elif IN_NEMO_EXTENSION
 PUBLIC void nemo_module_shutdown(void)
+#elif IN_PEONY_EXTENSION
+PUBLIC void peony_module_shutdown(void)
 #elif IN_THUNAR_EXTENSION
 PUBLIC void thunar_extension_shutdown(void);
 PUBLIC void thunar_extension_shutdown(void)
 #endif
 {
+#if IN_NEMO_EXTENSION
+	g_free(gtkhash_properties_nd_string);
+	gtkhash_properties_nd_string = NULL;
+#endif
 }
 
 #if IN_NAUTILUS_EXTENSION
@@ -584,6 +640,8 @@ PUBLIC void nautilus_module_list_types(const GType **types, int *num_types)
 PUBLIC void caja_module_list_types(const GType **types, int *num_types)
 #elif IN_NEMO_EXTENSION
 PUBLIC void nemo_module_list_types(const GType **types, int *num_types)
+#elif IN_PEONY_EXTENSION
+PUBLIC void peony_module_list_types(const GType **types, int *num_types)
 #elif IN_THUNAR_EXTENSION
 PUBLIC void thunar_extension_list_types(const GType **types, int *num_types);
 PUBLIC void thunar_extension_list_types(const GType **types, int *num_types)
