@@ -1,5 +1,5 @@
 /*
- *   Copyright (C) 2007-2011 Tristan Heaven <tristanheaven@gmail.com>
+ *   Copyright (C) 2007-2016 Tristan Heaven <tristan@tristanheaven.net>
  *
  *   This file is part of GtkHash.
  *
@@ -14,7 +14,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with GtkHash. If not, see <http://www.gnu.org/licenses/>.
+ *   along with GtkHash. If not, see <https://gnu.org/licenses/gpl-2.0.txt>.
  */
 
 #ifndef GTKHASH_NAUTILUS_PROPERTIES_H
@@ -39,14 +39,14 @@ struct page_s {
 	GtkTreeSelection *treeselection;
 	GtkCellRendererToggle *cellrendtoggle;
 	GtkMenu *menu;
-	GtkImageMenuItem *menuitem_copy;
+	GtkMenuItem *menuitem_copy;
 	GtkCheckMenuItem *menuitem_show_funcs;
 	GtkToggleButton *togglebutton_hmac;
 	GtkEntry *entry_check, *entry_hmac;
 	GtkButton *button_hash, *button_stop;
-	bool busy;
+	struct hash_file_s *hfile;
 	struct hash_func_s funcs[HASH_FUNCS_N];
-	struct hash_file_s hash_file;
+	bool busy;
 };
 
 void gtkhash_properties_idle(struct page_s *page);
